---- Enter vehicle info (fuel, etc)
--
-- @author: matbox
-- @date: 24.10.2018
--
----


Colors = {};
Colors.White  	   = {1, 1, 1, 0.3};
Colors.Green  	   = {0.2122, 0.5271, 0.0307, 1};
Colors.DarkGrey    = {0.0194, 0.0194, 0.0194, 1};
Colors.Orange 	   = {0.9301, 0.2874, 0.0130, 1};

showInfoDistance = 4.41;

enterVehicleInfo = {
	['targetAspectRatio'] = 16/9,
	['sizeRatio'] = 1
};

enterVehicleInfo.modDir = g_currentModDirectory;

function enterVehicleInfo.prerequisitesPresent(specializations)
    return true;
end;

local aspectRatioRatio = g_screenAspectRatio / enterVehicleInfo.targetAspectRatio;
local baseUVsPx = { 0,560, 75, 0};

if g_screenWidth > 1920 then
	enterVehicleInfo.sizeRatio = 1920 / g_screenWidth;
end;

function enterVehicleInfo:pxToNormal(px, dimension)
	local ret;
	if dimension == 'x' then
		ret = (px / 1920) * enterVehicleInfo.sizeRatio;
	else
		ret = (px / 1080) * enterVehicleInfo.sizeRatio * aspectRatioRatio;
	end;

	return ret;
end;

function enterVehicleInfo:load(savegame, xmlFile)
	self.pix = 'graph/graph_pixel.dds';
end;

function enterVehicleInfo:delete()
end;

function enterVehicleInfo:update(dt)
	local ix, iy, iz = getWorldTranslation(g_currentMission.player.rootNode);
	local rVehicle = table.getn(g_currentMission.steerables);
	for i=1, rVehicle do
		matbox = g_currentMission.steerables[i];	
		local vx, vy, vz = getWorldTranslation(matbox.exitPoint);
		local distance = Utils.vector3Length(vx-ix, vy-iy, vz-iz);
		local height = 1.4;
		if distance < showInfoDistance then
			if g_currentMission.player ~= nil then
				local ux, uy, uz = project(vx, vy+height, vz);
				if uz <= 1 then
					-- enter info
					setTextAlignment(RenderText.ALIGN_LEFT);
					setTextBold(false);
					setTextColor(unpack(Colors.White));
					renderText(ux+enterVehicleInfo:pxToNormal(8), uy+enterVehicleInfo:pxToNormal(17), getCorrectTextSize(0.013), string.format(g_i18n:getText("i_EnterVehicle")));
					
					setTextAlignment(RenderText.ALIGN_CENTER);
					setTextBold(false);
					setTextColor(unpack(Colors.White));
					renderText(ux+enterVehicleInfo:pxToNormal(-15), uy+enterVehicleInfo:pxToNormal(12), getCorrectTextSize(0.019), "^");
					
					-- fuel fill level/capacity
					setTextAlignment(RenderText.ALIGN_CENTER);
					setTextBold(false);
					setTextColor(unpack(Colors.White));
					renderText(ux+enterVehicleInfo:pxToNormal(89), uy+enterVehicleInfo:pxToNormal(17), getCorrectTextSize(0.013), tostring(math.floor(matbox.fuelFillLevel) .. "l" .. "/" .. matbox.fuelCapacity .. "l"));
					
					
					-- enter background
					self.enterVehicleIconBgPosX = enterVehicleInfo:pxToNormal(-54, 'x');
					self.enterVehicleIconBgPosY = enterVehicleInfo:pxToNormal(uy-2, 'y');
					self.enterVehicleIconBgWidth = enterVehicleInfo:pxToNormal(153, 'x');
					self.enterVehicleIconBgHeight = enterVehicleInfo:pxToNormal(48, 'y');
					
					self.enterVehicleIconBg = Overlay:new('enterVehicleIconBg', Utils.getFilename(self.pix, enterVehicleInfo.modDir), ux+self.enterVehicleIconBgPosX, uy+self.enterVehicleIconBgPosY, self.enterVehicleIconBgWidth, self.enterVehicleIconBgHeight);
					self.enterVehicleIconBg:setColor(unpack(Colors.Green))
					self.enterVehicleIconBg:render();
					--
					self.enterVehicleTextBgPosX = enterVehicleInfo:pxToNormal(0, 'x');
					self.enterVehicleTextBgPosY = enterVehicleInfo:pxToNormal(uy, 'y');
					self.enterVehicleTextBgWidth = enterVehicleInfo:pxToNormal(97, 'x');
					self.enterVehicleTextBgHeight = enterVehicleInfo:pxToNormal(44, 'y');
					
					self.enterVehicleTextBg = Overlay:new('enterVehicleTextBg', Utils.getFilename(self.pix, enterVehicleInfo.modDir), ux+self.enterVehicleTextBgPosX, uy+self.enterVehicleTextBgPosY, self.enterVehicleTextBgWidth, self.enterVehicleTextBgHeight);
					self.enterVehicleTextBg:setColor(unpack(Colors.DarkGrey));
					self.enterVehicleTextBg:render();
					
					-- fuel background
					self.fuelVehicleBgPosX = enterVehicleInfo:pxToNormal(107, 'x');
					self.fuelVehicleBgPosY = enterVehicleInfo:pxToNormal(uy-2, 'y');
					self.fuelVehicleBgWidth = enterVehicleInfo:pxToNormal(102, 'x');
					self.fuelVehicleBgHeight = enterVehicleInfo:pxToNormal(48, 'y');
					
					self.fuelVehicleBg = Overlay:new('fuelVehicleBg', Utils.getFilename(self.pix, enterVehicleInfo.modDir), ux+self.fuelVehicleBgPosX, uy+self.fuelVehicleBgPosY, self.fuelVehicleBgWidth, self.fuelVehicleBgHeight);
					self.fuelVehicleBg:setColor(unpack(Colors.Orange));
					self.fuelVehicleBg:render();
					--
					self.fuelVehicleLevelBgPosX = enterVehicleInfo:pxToNormal(109, 'x');
					self.fuelVehicleLevelBgPosY = enterVehicleInfo:pxToNormal(uy, 'y');
					self.fuelVehicleLevelBgWidth = enterVehicleInfo:pxToNormal(98, 'x');
					self.fuelVehicleLevelBgHeight = enterVehicleInfo:pxToNormal(44, 'y');
					
					self.fuelVehicleLevelBg = Overlay:new('fuelVehicleLevelBg', Utils.getFilename(self.pix, enterVehicleInfo.modDir), ux+self.fuelVehicleLevelBgPosX, uy+self.fuelVehicleLevelBgPosY, self.fuelVehicleLevelBgWidth, self.fuelVehicleLevelBgHeight);
					self.fuelVehicleLevelBg:setColor(unpack(Colors.DarkGrey));
					self.fuelVehicleLevelBg:render();
				end;
			end;
		end;
	end;
end;

function enterVehicleInfo:updateTick(dt)
end;

function enterVehicleInfo:draw()
end;

function enterVehicleInfo:mouseEvent(posX, posY, isDown, isUp, button)
end;

function enterVehicleInfo:keyEvent(unicode, sym, modifier, isDown)
end;